.. _bibliography:
.. index:: Bibliography

Bibliography
************

.. [BorHua98]
   | M. Born and K. Huang
   | *Dynamical Theory of Crystal Lattices*
   | Oxford University Press (1998)
   | `ISBN: 0198503695 <https://global.oup.com/academic/product/dynamical-theory-of-crystal-lattices-9780198503699>`_

.. [BroHasFan21]
  | J. Brorsson, A. Hashemi, Z. Fan, E. Fransson, F. Eriksson, T. Ala-Nissila, A. V. Krasheninnikov, H. Komsa, and P. Erhart
  | *Efficient calculation of the lattice thermal conductivity by atomistic simulations with ab-initio accuracy*
  | Advanced Theory and Simulations **4**,  2100217 (2021)
  | `doi: 10.1002/adts.202100217 <http://doi.org/10.1002/adts.202100217>`_

.. [EriFraErh19]
   | F. Eriksson, E. Fransson, and P. Erhart
   | *The Hiphive Package for the Extraction of High-Order Force Constants by Machine Learning*
   | Advanced Theory and Simulations **2**, 1800184 (2019)
   | `doi: 10.1002/adts.201800184 <https://doi.org/10.1002/adts.201800184>`_

.. [ErrCalMau14]
   | I. Errea, M. Callandra, and F. Mauri
   | *Anharmonic free energies and phonon dispersions from the stochastic self-consistent harmonic approximation: Application to platinum and palladium hydrides*
   | Physical Review B **89**, 064302 (2014)
   | `doi: 10.1103/PhysRevB.89.064302 <http://doi.org/10.1103/PhysRevB.89.064302>`_

.. [EsfSto08]
   | K. Esfarjani and H. T. Stokes
   | *Method to extract anharmonic force constants from first principles calculations*,
   | Physical Review B **77**, 144112 (2008);
   | `doi: 10.1103/PhysRevB.77.144112 <http://doi.org/10.1103/PhysRevLett.77.144112>`_

.. [FraEriErh20]
   | E. Fransson, F. Eriksson, and P. Erhart
   | *Efficient construction of linear models in materials modeling and applications to force constant expansions*
   | npj Computational Materials **6**, 135 (2020)
   | `doi: 10.1038/s41524-020-00404-5 <https://doi.org/10.1038/s41524-020-00404-5>`_

.. [Ful10]
   | B. Fultz
   | *Vibrational thermodynamics of materials*
   | Progress in Materials Science **55**, 247 (2010)
   | `doi: 10.1016/j.pmatsci.2009.05.002 <http://doi.org/10.1016/j.pmatsci.2009.05.002>`_

.. [HelAbrSim11]
   | O. Hellman, I. A. Abrikosov, and S. I. Simak
   | *Lattice dynamics of anharmonic solids from first principles*
   | Physical Review B **84**, 180301 (2011)
   | `doi: 10.1103/PhysRevB.84.180301 <http://doi.org/10.1103/PhysRevB.84.180301>`_

.. [LiCarKat14]
   | W. Li, J. Carrete, N. A. Katcho, and N. Mingo
   | *ShengBTE: A solver of the Boltzmann transport equation for phonons*
   | Computer Physics Communications **185**, 1747 (2014)
   | `doi: 10.1016/j.cpc.2014.02.015 <http://doi.org/10.1016/j.cpc.2014.02.015>`_

.. [ParLiKaw97]
   | K. Parlinski, Z. Q. Li, and Y. Kawazoe
   | *First-Principles Determination of the Soft Mode in Cubic ZrO:sub:`2`$*,
   | Physical Review Letters **78**, 4063 (1997);
   | `doi: 10.1103/PhysRevLett.78.4063 <http://doi.org/10.1103/PhysRevLett.78.4063>`_

.. [PedVarGra11]
   | F. Pedregosa *et al.*,
   | *Scikit-Learn: Machine Learning in Python*,
   | Journal of Machine Learning Research **12**, 2825 (2011)

.. [SanAndAsp15]
   | J. N. Sanders, X. Andrade, and Alán Aspuru-Guzik
   | *Compressed Sensing for the Fast Computation of Matrices: Application to Molecular Vibrations*,
   | ACS Central Science **1**, 24 (2015);
   | `doi: 10.1021/oc5000404 <http://doi.org/10.1021/oc5000404>`_

.. [TogTan15]
   | A. Togo and I Tanaka
   | *First principles phonon calculations in materials science*,
   | Scripta Materialia **108**, 1 (2015);
   | `doi: 10.1016/j.scriptamat.2015.07.021 <http://doi.org/10.1016/j.scriptamat.2015.07.021>`_

.. [TogChaTan15]
   | A. Togo, L. Chaput, and I. Tanaka
   | *Distributions of phonon lifetimes in Brillouin zones*,
   | Physical Review B **91**, 094306 (2015);
   | `doi: 10.1103/PhysRevB.91.094306 <http://doi.org/10.1103/PhysRevB.91.094306>`_

.. [TadGohTsu14]
   | T. Tadano, Y. Gohda, and S. Tsuneyuki
   | *Anharmonic force constants extracted from first-principles molecular dynamics: applications to heat transfer simulations*,
   | Physical Review B **91**, 094306 (2015);
   | `doi: 10.1103/PhysRevB.91.094306 <http://doi.org/10.1103/PhysRevB.91.094306>`_

.. [Wal98]
   | D. C. Wallace
   | *Thermodynamics of Crystals*
   | Dover Publications (1998)
   | ISBN: 0-486-40212-6

.. [ZhoNieXia14]
   | F. Zhou, W. Nielson, Y. Xia, and V. Ozolins
   | *Lattice anharmonicity and thermal conductivity from compressive sensing of first-principles calculations*,
   | Physical Review Letters **113**, 185501 (2014);
   | `doi: 10.1103/PhysRevLett.113.185501 <http://doi.org/10.1103/PhysRevLett.113.185501>`_

.. [Zim60]
   | J. M. Ziman
   | *Electrons and Phonons*
   | Oxford University Press (1960)
